/*
 * Copyright (c) 2022-2024. Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.settings;

import java.util.Objects;
import java.util.Optional;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;

import de.ozgcloud.user.UserService;
import de.ozgcloud.user.common.logging.OzgCloudLogging;

@OzgCloudLogging
@ApplicationScoped
class UserSettingsService {

	@Inject
	UserService userService;

	@Inject
	UserSettingsRepository repository;

	public Optional<UserSettings> updateByUserId(String userId, UserSettings newSettings) {
		var settings = newSettings.toBuilder().vorgangCreated(newSettings.getNotificationsSendFor() == NotificationsSendFor.ALL).build();
		return repository.updateByUserId(userId, settings);
	}

	public UserSettings getByUserId(String userId) {
		var user = userService.getById(userId);

		if (Objects.isNull(user.getUserSettings())) {
			return buildInitialUserSettings();
		}

		return user.getUserSettings();
	}

	private UserSettings buildInitialUserSettings() {
		return UserSettings.builder().notificationsSendFor(NotificationsSendFor.NONE).build();
	}

}
