/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user;

import java.util.List;

import org.bson.types.ObjectId;

import de.ozgcloud.user.settings.UserSettings;
import de.ozgcloud.user.settings.UserSettingsTestFactory;

public class UserTestFactory {

	public static final ObjectId ID = new ObjectId();
	public static final String KEYCLOAK_USER_ID = "aec115b5-67be-42c9-a693-36d4d711a87a";
	public static final String ID_STR = ID.toHexString();

	public static final String FIRST_NAME = "Sabine";
	public static final String LAST_NAME = "Sach";
	public static final String FULL_NAME = FIRST_NAME + " " + LAST_NAME;
	public static final String FULL_NAME_REVERSED = LAST_NAME + " " + FIRST_NAME;
	public static final String USER_NAME = "sabine";
	public static final long LAST_SYNC_TIMESTAMP = 1001L;
	public static final String EMAIL = "sabine.sach@ozgcloud.de";
	public static final String EXTERNAL_ID = "aec115b5-67be-42c9-a693-36d4d711a87a";
	public static final String ORGANISTATIONSEINHEITEN_ID = "0815";
	public static final List<String> ROLES = List.of("ROLE_1", "POSTSTELLE");
	public static final UserSettings USER_SETTINGS = UserSettingsTestFactory.create();

	public static User create() {
		return createBuilder().build();
	}

	public static User.UserBuilder createBuilder() {
		return User.builder()
				.id(ID)
				.keycloakUserId(KEYCLOAK_USER_ID)
				.firstName(FIRST_NAME)
				.lastName(LAST_NAME)
				.fullName(FULL_NAME)
				.fullNameReversed(FULL_NAME_REVERSED)
				.username(USER_NAME)
				.lastSyncTimestamp(LAST_SYNC_TIMESTAMP)
				.email(EMAIL)
				.externalId(EXTERNAL_ID)
				.organisationsEinheitId(ORGANISTATIONSEINHEITEN_ID)
				.roles(ROLES)
				.userSettings(USER_SETTINGS);
	}
}
