package de.ozgcloud.user.common.migration;

import static de.ozgcloud.user.common.migration.M001_SetNewAndMigrateUserSettings.*;
import static org.assertj.core.api.Assertions.*;

import java.util.Map;

import jakarta.inject.Inject;

import org.bson.Document;
import org.eclipse.microprofile.config.inject.ConfigProperty;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import com.mongodb.client.MongoClient;
import com.mongodb.client.MongoCollection;

import de.ozgcloud.user.common.MongoDbTestProfile;
import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.junit.TestProfile;

@QuarkusTest
@TestProfile(MongoDbTestProfile.class)
class M001_SetNewAndMigrateUserSettingsITCase {

	static final String USERNAME_FIELD = "username";

	@ConfigProperty(name = "quarkus.mongodb.database")
	String database;

	@Inject
	MongoClient mongoClient;

	private M001_SetNewAndMigrateUserSettings migration;
	private MongoCollection<Document> userCollection;

	@BeforeEach
	void setUp() {
		migration = new M001_SetNewAndMigrateUserSettings(mongoClient.getDatabase(database));
	}

	@BeforeEach
	void initDatabase() {
		userCollection = mongoClient.getDatabase(database).getCollection(USER_COLLECTION_NAME);
		userCollection.drop();
		userCollection.insertOne(new Document(
				Map.of(USERNAME_FIELD, "alluser",
						USER_SETTINGS_FIELD, Map.of(NOTIFICATIONS_SEND_FOR_FIELD, "ALL"))));
		userCollection.insertOne(new Document(Map.of(USERNAME_FIELD, "noneuser",
				USER_SETTINGS_FIELD, Map.of(NOTIFICATIONS_SEND_FOR_FIELD, "NONE"))));
		userCollection.insertOne(new Document(Map.of(USERNAME_FIELD, "nosettings")));
	}

	@Test
	void shouldMigrateNotificationSendFor_ALL() {
		migration.migrationMethod();

		var user = userCollection.find(new Document(Map.of(USERNAME_FIELD, "alluser")));
		assertThat(user.first()).contains(
				entry(USER_SETTINGS_FIELD, new Document(Map.of(
						NOTIFICATIONS_SEND_FOR_FIELD, "ALL",
						VORGANG_CREATED_FIELD, true,
						VORGANG_ASSIGNED_TO_USER_FIELD, true,
						POSTFACH_NACHRICHT_FROM_ANTRAGSTELLER_FIELD, true,
						WIEDERVORLAGE_DUE_TODAY, true))));
	}

	@Test
	void shouldMigrateNotificationSendFor_NONE() {
		migration.migrationMethod();

		var user = userCollection.find(new Document(Map.of(USERNAME_FIELD, "noneuser")));
		assertThat(user.first()).contains(
				entry(USER_SETTINGS_FIELD, new Document(Map.of(
						NOTIFICATIONS_SEND_FOR_FIELD, "NONE",
						VORGANG_CREATED_FIELD, false,
						VORGANG_ASSIGNED_TO_USER_FIELD, true,
						POSTFACH_NACHRICHT_FROM_ANTRAGSTELLER_FIELD, true,
						WIEDERVORLAGE_DUE_TODAY, true))));
	}

	@Test
	void shouldSetDefaultSettings() {
		migration.migrationMethod();

		var user = userCollection.find(new Document(Map.of(USERNAME_FIELD, "nosettings")));
		assertThat(user.first()).contains(
				entry(USER_SETTINGS_FIELD, new Document(Map.of(
						NOTIFICATIONS_SEND_FOR_FIELD, "NONE",
						VORGANG_CREATED_FIELD, false,
						VORGANG_ASSIGNED_TO_USER_FIELD, true,
						POSTFACH_NACHRICHT_FROM_ANTRAGSTELLER_FIELD, true,
						WIEDERVORLAGE_DUE_TODAY, true))));
	}
}